Technical Documentation: Client
===============================

.. attention::

   This section of the Isso documentation is incomplete. Please help by expanding it.

   Click the ``Edit on GitHub`` button in the top right corner and read the
   GitHub Issue named
   `Improve & Expand Documentation <https://github.com/isso-comments/isso/issues/797>`_
   for further information.

   **What's missing?**

   - JS, webpack (explain why each is needed)
   - Coding standards (ES5?), goals (compartmentalization, testability,
     ease of maintenance)
   - Compatibility: Browser/IE versions, used ES versions -
     keep updated for JS and CSS features (e.g. CSS vars)

   ... and other things about the client that should be documented.
